import http from '../../src/http';
import util from '../../src/libs/util';
import dd from 'gdt-jsapi';

Page({
  data: {
    borrow_code : '',
    name: '',
    destination: '',
    start_time : '',
    end_time : '',
    reason: '',
    isPoliceCar: '',
    policeCar: '',
    carType: '',
    timeNumber: '',
    carTypeList: ['5座', '7座', '中型面包车'],
    isPoliceCarList: ['警车', '非警车'],
    reasons: ['区内执法执勤', '市内出差', '市外出差', '省外出差'],
    url: {
      getProcess: '/api/Sys_Process/GetProcess',
      save: '/api/T_Borrow/SaveOrUpdate'
    }
  },
  onLoad() {
    this.getBorrowCode()
  },
  getBorrowCode(){
    http.get('/jeecg/sys/fillRule/testFillRule', {ruleCode: 'shop_order_num'}).then(res => {
      if (res.success) {
        this.setData({
          borrow_code : res.result,
          name : getApp().globalData.userInfo.name,
        });
      } else {
        util.ddToast({ type: 'fail', text: res.msg })
      }
    })
  },
  onClear(e) {
    this.setData({
      [e.target.dataset.field]: ''
    });
  },
  dateStartPicker() {
    const _this = this
    my.datePicker({
      format: 'yyyy-MM-dd HH:mm',
      success: (res) => {
        this.setData({
          start_time: res.date,
          timeNumber: (_this.data.end_time && res.date) ? _this.getIntervalHour(res.date, _this.data.end_time) : 0
        })
      }
    })
  },
  dateEndPicker() {
    const _this = this
    my.datePicker({
      format: 'yyyy-MM-dd HH:mm',
      success: (res) => {
        this.setData({
          end_time: res.date,
          timeNumber: (_this.data.start_time && res.date) ? _this.getIntervalHour(_this.data.start_time, res.date) : 0
        })
      }
    })
  },
  getIntervalHour(dt1,dt2) {
    if(typeof(dt1)=="string") {
      dt1=new Date(dt1.replace(/-/,'/'));
      dt2=new Date(dt2.replace(/-/,'/'));
    }
    var res = dt2-dt1;
    if(isNaN(res))
    throw Error("invalid dates arguments");
    return Math.trunc(res/(1000*60*60));
  },
  carTypePickerChange() {
    my.showActionSheet({
      title: '选择车辆种类',
      items: this.data.carTypeList,
      cancelButtonText: '取消',
      success: (res) => {
        this.setData({
          carType: this.data.carTypeList[res.index]
        });
      },
    });
  },
  isPoliceCarPickerChange() {
    my.showActionSheet({
      title: '选择车辆类型',
      items: this.data.isPoliceCarList,
      cancelButtonText: '取消',
      success: (res) => {
        this.setData({
          isPolice: this.data.isPoliceCarList[res.index],
          isPoliceCar: res.index
        });
      },
    });
  },
  reasonPickerChange() {
    my.showActionSheet({
      title: '选择工作内容',
      items: this.data.reasons,
      cancelButtonText: '取消',
      success: (res) => {
        this.setData({
          reason: this.data.reasons[res.index]
        });
      },
    });
  },
  onBzInput(e) {
    this.setData({
      bz: e.detail.value
    });
  },
  handleSubmit(e) {
    let formData = {}
    formData = e.detail.value
    formData.userid = getApp().globalData.userInfo.userId
    formData.carType = this.data.carType
    formData.isPoliceCar = this.data.isPoliceCar
    formData.reason = this.data.reason
    formData.start_time = this.data.start_time
    formData.end_time = this.data.end_time
    if (!formData.carType) {
      return util.ddToast({ type: 'fail', text: '请选择车辆种类' })
    }
    if (!this.data.isPolice) {
      return util.ddToast({ type: 'fail', text: '请选择车辆类型' })
    }
    if (!formData.reason) {
      return util.ddToast({ type: 'fail', text: '请选择任务类型' })
    }
    if (!formData.destination) {
      return util.ddToast({ type: 'fail', text: '请输入任务地点' })
    }
    if (!formData.start_time) {
      return util.ddToast({ type: 'fail', text: '请选择开始时间' })
    } 
    if (!formData.end_time) {
      return util.ddToast({ type: 'fail', text: '请选择结束时间' })
    }
    if (formData.timeNumber < 0) {
      return util.ddToast({ type: 'fail', text: '时长不能为负数' })
    }
    let code = ''
    if (formData.timeNumber < 24 && (formData.reason == '区内执法执勤' || formData.reason == '市内出差')) {
      code = 'bmldsh'
    }
    else if (formData.reason == '省外出差' || formData.timeNumber > 120) {
      code = 'zwsh'
    } else {
      code = 'jbksh'
    }
    const _this = this
    http.post(getApp().globalData.service + this.data.url.getProcess, {code: code, stepId: "",flowGateway: ""}).then(res => {
      if(res.Success) {
        formData = Object.assign(formData, res.result)
        http.post(getApp().globalData.service + _this.data.url.save, formData).then(res => {
          if (res.Success) {
            dd.redirectTo({
              url: '../myApply/myApply'
            })
          } else {
            util.ddToast({ type: 'fail', text: res.Message })
          }
        })
      } else {
        util.ddToast({ type: 'fail', text: res.Message })
      }
    })
  },
});
